@@ -10,7 +10,7 @@
  *******************************************************************************/
 /*eslint-env node */
 /*globals configs:true val:true*/
-var api = require('../api'), writeError = api.writeError;
+var api = require('../api'), writeError = api.writeError, writeResponse = api.writeResponse;
 var args = require('../args');
 var clone = require('./clone');
 var express = require('express');
@@ -21,22 +21,23 @@ module.exports = {};
 
 module.exports.router = function(options) {
 	var fileRoot = options.fileRoot;
-	if (!fileRoot) { throw new Error('options.root is required'); }
-	var contextPath = options.options.configParams["orion.context.path"] || "";
-
+	var gitRoot = options.gitRoot;
+	if (!fileRoot) { throw new Error('options.fileRoot is required'); }
+	if (!gitRoot) { throw new Error('options.gitRoot is required'); }
+	
 	return express.Router()
 	.use(bodyParser.json())
-	.get('/clone'+ contextPath + '/file*', getConfig)
-	.get('/:key/clone'+ contextPath + '/file*', getAConfig)
-	.delete('/:key/clone'+ contextPath + '/file*', deleteConfig)
-	.put('/:key/clone'+ contextPath + '/file*', putConfig)
-	.post('/clone'+ contextPath + '/file*', postConfig);
+	.get('/clone'+ fileRoot + '*', getConfig)
+	.get('/:key/clone'+ fileRoot + '*', getAConfig)
+	.delete('/:key/clone'+ fileRoot + '*', deleteConfig)
+	.put('/:key/clone'+ fileRoot + '*', putConfig)
+	.post('/clone'+ fileRoot + '*', postConfig);
 
 function configJSON(key, value, fileDir) {
 	return {
 		"Key": key,
-		"CloneLocation": contextPath + "/gitapi/clone" + fileDir,
-		"Location": contextPath + "/gitapi/config/" + util.encodeURIComponent(key) + "/clone" + fileDir,
+		"CloneLocation": gitRoot + "/clone" + fileDir,
+		"Location": gitRoot + "/config/" + util.encodeURIComponent(key) + "/clone" + fileDir,
 		"Value": Array.isArray(value) ? value : [value]
 	};
 }
@@ -62,7 +63,7 @@ function getAConfig(req, res) {
 				value = config[section] && config[section][name];
 			}
 			if (value !== undefined) {
-				res.status(200).json(configJSON(key, value, fileDir));
+				writeResponse(200, res, null, configJSON(key, value, fileDir), true);
 			} else {
 				writeError(404, res, "There is no config entry with key provided");
 			}
@@ -87,12 +88,12 @@ function getConfig(req, res) {
 
 			getFullPath(config, "");
 
-			res.status(200).json({
+			writeResponse(200, res, null, {
 				"Children": configs,
-				"CloneLocation": contextPath + "/gitapi/clone" + fileDir,
-				"Location": contextPath + "/gitapi/config/clone"+ fileDir,
+				"CloneLocation": gitRoot + "/clone" + fileDir,
+				"Location": gitRoot + "/config/clone"+ fileDir,
 				"Type": "Config"
-			});
+			}, true);
 
 			function getFullPath(config, prefix) {
 				if (typeof config !== "object" || Array.isArray(config)) {
@@ -139,8 +140,7 @@ function updateConfig(req, res, key, value, callback) {
 					}
 					if (result.value) {
 						var resp = configJSON(key, result.value, fileDir);
-						res.setHeader("Location", resp.Location);
-						res.status(result.status).json(resp);
+						writeResponse(result.status, res, {"Location":resp.Location}, resp, true);
 					} else {
 						res.status(result.status).end();
 					}
